#
# spec file for package bmake
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Building Fedora packages in OBS
%{!?ext_man: %define ext_man .gz}
%if 0%{?fedora_version}
%global debug_package %{nil}
%endif

Name:           bmake
Version:        20230723
Release:        1.5
Summary:        The NetBSD make(1) tool
License:        BSD-2-Clause AND BSD-3-Clause AND BSD-4-Clause
Group:          Development/Tools/Building
URL:            https://ftp.NetBSD.org/pub/NetBSD/misc/sjg/
Source0:        https://ftp.NetBSD.org/pub/NetBSD/misc/sjg/bmake-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE allow-overriding-compiler-variables.patch -- Based on Linux.sys.mk which was previously shipped with this package
# patch generated using `git diff master opensuse` from https://github.com/RichardsonAlex/bmake
Patch0:         allow-overriding-compiler-variables.patch
# PATCH-FIX-OPENSUSE vs. E: env-script-interpreter meta2deps.py /usr/bin/env python
Patch1:         bmake-env-script-interpreter.diff

%description
bmake, the NetBSD make(1) tool, is a program designed to simplify the
maintenance of other programs.  The input of bmake is a list of specifications
indicating the files upon which the targets (programs and other files) depend.
bmake then detects which targets are out of date based on their dependencies
and triggers the necessary commands to bring them up to date when that happens.

bmake is similar to GNU make, even though the syntax for the advanced features
supported in Makefiles is very different.

%prep
%autosetup -p1 -n %{name}

%build
unset MAKEFLAGS
env CFLAGS="%{optflags} -g" \
./boot-strap -o Linux \
  --prefix="%{_prefix}" \
  --sysconfdir="%{_sysconfdir}" \
  --with-default-sys-path="%{_datadir}/mk" \
  --without-filemon \
  op=build

%install
./boot-strap -o Linux \
  --prefix="%{_prefix}" \
  --sysconfdir="%{_sysconfdir}" \
  --with-default-sys-path="%{_datadir}/mk" \
  --install-prefix="%{_prefix}" \
  --install-destdir=%{buildroot} \
  op=install

%check
./boot-strap op=test

%files
%doc ChangeLog README
%{_bindir}/bmake
%{_mandir}/man1/bmake.1%{?ext_man}
%{_datadir}/mk/

%changelog
* Wed Jul 26 2023 Matej Cepl <mcepl@suse.com>
- Update to 20230723:
  - There were many changes, like really many. See ChangeLog
    which has been packaged for the list of them.
* Wed Jul 26 2023 Matej Cepl <mcepl@suse.com>
- Refresh patches, remove %%patchN construct.
* Wed Jun 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update bmake-env-script-interpreter.diff to switch to interpreter
  to python3.
* Sun Jun 14 2020 Dmitriy Perlow <dap.darkness@gmail.com>
- Updated allow-overriding-compiler-variables.patch.
- Update to version 20200606:
  * make.1: cleanup
  * Makefile: fix depends for main.o which broke MAKE_VERSION
  * dir.c: cached_stats - don't confuse stat and lstat results.
  * var.c: add :Or for reverse sort.
  * configure.in: add AC_PROG_CC_C99 for mipspro compiler
    also if --with-filemon= specifies path to filemon.h
    set use_filemon=dev
  * dirname.c: remove include of namespace.h
  * modified dollar tests to avoid shell dependencies
  * new tests for .INCLUDEFROM
  * unit-tests/dollar.mk: tweak  '1 dollar literal' test
    to not depend so much on shell behavior
  * unit test for dollar handling
  * str.c: empty string does not match %% pattern
    plus unit-test changes
  * var.c: import handling of old sysV style modifier using '%%'
  * str.c: refactor brk_string
  * unit-tests: add test case for lazy conditions
  * configure.in: use_makefile=no for cygwin et al.
    case insensitive filesystems just don't work if both
    makefile and Makefile exist.
  * meta.c: meta_oodate, CHECK_VALID_META is too aggressive for CMD
    a blank command is perfectly valid.
  * make.h: extern debug_file
  * meta.c: meta_oodate, check for corrupted meta file
    earlier and more often.
  * boot-strap: unset MAKEFLAGS
  * meta.c: meta_compat_parent check for USE_FILEMON
    patch from Soeren Tempel
  * meta.c: fix compat mode, need to call meta_job_output()
  * job.c: extra fds for meta mode not needed if using filemon_dev
  * meta.c: avoid passing NULL to filemon_*() when meta_needed()
    returns FALSE.
  * filemon/filemon_{dev,ktrace}.c: allow selection of
    filemon implementation.  filemon_dev.c uses the kernel module
    while filemon_ktrace.c leverages the fktrace api available in
    NetBSD.  filemon_ktrace.c can hopefully form the basis for
    adding support for other tracing mechanisms such as strace on
    Linux.
  * meta.c: when target is out-of-date per normal make rules
    record value of .OODATE in meta file.
  * parse.c: don't pass NULL to realpath(3)
    some versions cannot handle it.
  * parse.c: ParseDoDependency: free paths rather than assert
  * configure.in: add --without-makefile to avoid generating
    makefile and make-bootstrap.sh
  * include Makefile.inc if it exists
  * Use Makefile and Makefile.config.in in unit-tests
    so we can use just: make obj && make && make test
    when bmake is already available.
    We add --without-makefile to CONFIGURE_ARGS in this case.
  * tweak bsd.after-import.mk (captures Makefile.config etc
    after import to FreeBSD for example) to cope with all the above.
  * parse.c: ParseVErrorInternal use .PARSEDIR
    and apply if relative, and then use .PARSEFILE
    for consistent result.
  * parse.c: ParseVErrorInternal use .CURDIR if .PARSEDIR
    is relative
  * var.c: avoid SEGFAULT in .unexport-env
    when MAKELEVEL is not set
  * fix for unit-tests/varquote.mk on Debian
  * var.c: add :q
  * dir.c: cleanup caching of stats
  * Makefile.config.in: use += where it makes sense.
* Wed Sep 11 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 20181221:
  * For full list of changes see provided Changelog
* Fri Jul 13 2018 dap.darkness@gmail.com
- Removed already upstreamed bmake-strlcpy-explicit.patch.
- Added bmake-env-script-interpreter.diff.
- Update to version 20180512:
  * job.c: skip polling job token pipe
  * parse.c: be more cautious about detecting depenency line
    rather than sysV style include.
  * parse.c: avoid calling sysconf for every call to loadfile
  * var.c: Var_Set handle NULL value anytime.
  * parse.c: do not treat .info as warning with -W
  * var.c: Var_Append use Var_Set if var not previously set
    so that VAR_CMD is handled correctly.
    Add a suitable unit-test.
  * var.c: do not append to variable set on command line
    add unit-test to catch this.
  * main.c: ignore empty MAKEOBJDIR
  * meta.c: if target is in subdir we only need subdir name in
    meta_name.
  * compat.c: pass SIGINT etc onto child and wait for it to exit
    before we self-terminate.
  * aclocal.m4: use AC_LINK_IFELSE for AC_C___ATTRIBUTE__
    since AC_TRY_COMPILE puts input inside main()
    which upsets modern compilers.
  * Makefile.config.in:
    make @prefix@ @machine*@ and @default_sys_path@ defaults.
  * unit-tests/dotwait.mk: redirect stderr through pipe for more
    consistent result on some platforms.
  * machine.sh: entry for AIX
  * VERSION (_MAKE_VERSION): Move the setting of _MAKE_VERSION
    to a file that can be included by configure as well as make.
    This allows configure to set set _MAKE_VERSION in make-bootstrap.sh
* Wed Jul 19 2017 dap.darkness@gmail.com
- bmake-strlcpy-explicit.patch was replaced by upstream's one.
- Update to version 20170711:
  * main.c: refactor to reduce size of main function.
    add -v option to always fully expand values.
  * meta.c: ensure command output in meta file has ending newline
    even when filemon not being used.
    When matching ${.MAKE.META.IGNORE_PATTERNS} do not use
    pathname via ':L' since any ':' in pathname breaks that.
    Instead set a '${.p.}' to pathname in the target context and
    use that.
* Tue Jul 18 2017 dimstar@opensuse.org
- Add bmake-strlcpy-explicit.patch: ensure strlcpy is not defined
  implicit.
- Do not de-FORTIFY the sources, use proper optflags. Above patch
  ensures strlcpy is not implicit declared.
* Sun Jun 18 2017 dap.darkness@gmail.com
- Let's skip optflags macro using to fix all builds.
  "-D_FORTIFY_SOURCE=0" for some reason doesn't fix x64.
* Fri May 19 2017 dziolkowski@suse.com
- Update to version 20170510
  * For full list of changes see provided Changelog
- Fix allow-overriding-compiler-variables.patch to work with new version
* Wed Apr  5 2017 mpluskal@suse.com
- Update to version 20170326
  * For full list of changes see provided Changelog
- Use https url for downloading
* Wed Nov 23 2016 arichardson.kde@gmail.com
- Update to 20160926
  * Makefile (_MAKE_VERSION): 20160926
    + Merge with NetBSD make, pick up
    + support for .DELETE_ON_ERROR: (remove targets that fail)
  * Makefile MAN: tweak .Dt to match ${PROG}
* Wed Nov 23 2016 arichardson.kde@gmail.com
- Install the .mk files as well
- Use allow-overriding-compiler-variables.patch instead overwriting the
  installed file with Linux.sys.mk
* Thu Sep 15 2016 rdodopoulos@suse.com
- 20160818
  * its a neater number; pick up whitespace fixes to man page.
  * Merge with NetBSD make, pick up
    + meta.c: move handling of .MAKE.META.IGNORE_* to meta_ignore()
    so we can call it before adding entries to missingFiles.
    Thus we do not track files we have been told to ignore.
    + meta_oodate: apply .MAKE.META.IGNORE_FILTER (if defined) to
    pathnames, and skip if the expansion is empty.
    Useful for dirdeps.mk when checking DIRDEPS_CACHE.
    + meta.c: remove all missingFiles entries that match a deleted
    dir.
    + main.c: set .ERROR_CMD if possible.
    + dir.c: extend mtimes cache to others via cached_stat()
    + meta.c: missing filemon data is only relevant if we read a
    meta file.
    Also do not return oodate for a missing metafile if gn->path
    points to .CURDIR
    + cached_realpath(): avoid hitting filesystem more than necessary.
    + meta.c: refactor need_meta decision, add knobs for
    missing meta file and filemon data wrt out-of-datedness.
* Tue Jun 14 2016 dap.darkness@gmail.com
- 20160528
  * boot-strap, make-bootstrap.sh.in: Makefile uses _MAKE_VERSION
- Removed bmake-MAKE_VERSION.diff so.
* Thu May 26 2016 dap.darkness@gmail.com
- Added bmake-MAKE_VERSION.diff to fix MAKE_VERSION variable
  that fixes mk-configure package configure error.
* Wed May 25 2016 dap.darkness@gmail.com
- 20160512
  * Merge with NetBSD make, pick up
    + meta.c: ignore paths that match .MAKE.META.IGNORE_PATTERNS
    this is useful for gcov builds.
    + propagate errors from filemon(4).
    + remove use of non-standard types u_int etc.
    + meta.c: apply realpath() before matching against metaIgnorePaths
    + allow makefile to set .MAKE.JOBS
  * Makefile (PROG_NAME): use ${_MAKE_VERSION}
* Sun May 15 2016 dap.darkness@gmail.com
- 20160315
  * Merge with NetBSD make, pick up:
    + fix handling of archive members;
    + meta.c: treat missing Read file same as Write,
    in case we Delete it.
  * Rename variable to avoid interference
    with checks for ${MAKE_VERSION}.
* Wed Mar 16 2016 mpluskal@suse.com
- 20160307
  * Merge with NetBSD make, pick up
    + var.c: fix :ts\nnn to be octal by default.
    + meta.c: meta_finish() to cleanup memory.
    + meta.c: allow meta file for makeDepend if makefiles want it.
    + var.c: add knob to control handling of '$$' in :=
    + var.c: add .export-literal allows us to fix sys.clean-env.mk
    post the changes to Var_Subst. Var_Subst now takes flags, and
    does not consume '$$' in :=
    + ar.c: preserve '$$' in :=
    + parse.c: add .dinclude for handling included makefile like
    .depend
- Use correct package group
* Sun Dec 27 2015 mpluskal@suse.com
- Update to 20151220
  * suff.c: re-initialize suffNull when clearing suffixes.
  * cond.c: CondCvtArg: avoid access beyond end of empty buffer.
  * meta.c: meta_oodate: use lstat(2) for checking link target in
    case it is a symlink.
  * var.c: avoid calling brk_string and Var_Export1 with empty
    strings.
* Sat Nov 14 2015 mpluskal@suse.com
- Update to 20151022
  * Makefile (MAKE_VERSION): 20151022
  * Add support for BSD/OS which lacks inttypes.h
    and really needs sys/param.h for sys/sysctl.h
    also 'type' is not a shell builtin.
  * var.c: eliminate uint32_t and need for inttypes.h
  * main.c: PrintOnError flush stdout before run .ERROR
  * parse.c: cope with _SC_PAGESIZE not being defined.
- For reso of changes see Changelog
- Tiny spec file polishing
* Mon Oct  5 2015 mpluskal@suse.com
- Update to 20150910
  * Merge with NetBSD make, pick up
    + main.c: with -w print Enter/Leaving messages for objdir too
    if necessary.
    + centralize shell metachar handling
  * FILES: add metachar.[ch]
* Wed Aug  5 2015 mpluskal@suse.com
- Update to 20150606
  * Merge with NetBSD make, pick up
    + o make.1: document .OBJDIR target
* Sun May 17 2015 dap.darkness@gmail.com
- Update to 20150505:
  * Merge with NetBSD make, pick up
    + cond.c: be strict about lhs of comparison when evaluating .if
    but less so when called from variable expansion.
    + unit-tests/cond2.mk: test various error conditions
    + job.c: use memmove() rather than memcpy()
    + document different handling of '-' in jobs mode vs compat
    + fix jobs mode so that '-' only applies to whole job
    when shell lacks hasErrCtl
    + meta.c: use separate vars to track lcwd and latestdir (read)
    per process
    + meta.c: close meta file in child
  * Add Bitrig patch from joerg@netbsd.org
  * Makefile: use BINDIR.bmake if set. Same for MANDIR and
    SHAREDIR. Handy for testing release candidates in various
    environments.
  * move initialization of savederr to block where it is used
    to avoid spurious warning from gcc5
* Fri Mar  6 2015 mpluskal@suse.com
- Cleanups spec file with spec-cleaner
- Update to 20141111
  * Makefile (MAKE_VERSION): 20141111 just a cooler number
  * Makefile (MAKE_VERSION): 20141105
  * Merge with NetBSD make, pick up
  - revert major overhaul of suffix handling and POSIX compliance
  - too much breakage and impossible to make backwards
    compatible.
  - we still have the new unit test structure which is ok.
  - meta.c ensure "-- filemon" is at start of line.
  * configure.in: test that result of getconf PATH_MAX is numeric
    and discard if not.  Apparently needed for Hurd.
  * Makefile (MAKE_VERSION): 20140830
  * Merge with NetBSD make, pick up
  - major overhaul of suffix handling
  - improved POSIX compliance
  - overhauled unit-tests
* Sat Sep 13 2014 vle@gmx.net
- Update to 20140620.
- Enabled unit tests.
* Sun Jun  1 2014 dap.darkness@gmail.com
- Imported from repoforge.
- SUSEficated.
* Mon Jan  2 2012 cheusov@NetBSD.org
- Update to 20111010 and adapted to Repoforge.
* Tue Dec  8 2009 lav@altlinux.ru
- add pkgsrc-mk-files require
* Wed Jul 29 2009 lav@altlinux.ru
- create dir for bmake macros
* Thu Jul 23 2009 vle@gmx.net
- Now bmake doesn't depend on mk-files
* Sun Jul 12 2009 lav@altlinux.ru
- initial build for ALT Linux Sisyphus
* Mon Feb 23 2009 rel-eng@lists.fedoraproject.org
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild
* Wed Jul  2 2008 jmmv@NetBSD.org
- Initial release for Fedora.
